%clear all;
close all;
clc;

%% Start
load('Undersampled_Signal.mat');
load('Oversampled_Signal.mat');

%% PSD
Gain = 31.33e3;

%% Overall PSD
% Oversampling
[oFreq, oPSD_Vsq]           = Calculate_PSD(Oversampled_Time, Oversampled_Signal, 1);
oPSD_Asq                    = oPSD_Vsq/Gain^2;
% Undersampling
[oFreq_Res, oPSD_Vsq_Res]   = Calculate_PSD(Undersampled_Time, Undersampled_Signal, 1);
oPSD_Asq_Res                = oPSD_Vsq_Res/Gain^2;
                                      
Smoothed_PSD_Asq            = smoothdata(oPSD_Asq, 'gaussian', 15);
Spec_Freq                   = oFreq;

Smoothed_PSD_Asq_Res        = smoothdata(oPSD_Asq_Res, 'gaussian', 7);
Spec_Freq_Res               = oFreq_Res;

%% Plot Time Signals
fid = figure;
x_min   = 25;
dx      = 0.3;
x_1     = Oversampled_Time    - Oversampled_Time(1) - x_min;
x_2     = Undersampled_Time   - Undersampled_Time(1) - x_min;
y_1     = Oversampled_Signal  - mean(Oversampled_Signal);
y_2     = Undersampled_Signal - mean(Undersampled_Signal);

plot(x_1, y_1, 'b-', 'LineWidth', 1.5);
hold on;
plot(x_2, y_2, 'r-', 'LineWidth', 1.5);

xlabel('$t=n/f_{\mathrm{s}}$ $[\mathrm{s}]$', 'FontSize', 15, 'Interpreter', 'latex');
xlim([0 dx]);
ylabel('$v_1(t=n/f_{\mathrm{s}})$ $[\mathrm{V}]$', 'FontSize', 15, 'Interpreter', 'latex');

legend({'$f_{\mathrm{s}}=83.3\,\mathrm{kHz}$', '$f_{\mathrm{s}}=50\,\mathrm{Hz}$'},...
            'FontSize', 12, 'Interpreter', 'latex', 'Orientation', 'vertical');

grid on;
grid minor
ax = gca;
ax.FontSize = 14;

%% Plot Power Spectral Densities
fid = figure;

x_1     = Spec_Freq;
x_2     = Spec_Freq_Res;
y_1     = Smoothed_PSD_Asq;
y_2     = Smoothed_PSD_Asq_Res;

loglog(x_1, y_1, 'b-', 'LineWidth', 1.5);
hold on;
loglog(x_2, y_2, 'r-', 'LineWidth', 1.5);
loglog([2, 2], [1e-30, 1e-10], 'k:', 'LineWidth', 2);
loglog([25, 25], [1e-30, 1e-10], 'k:', 'LineWidth', 2);

ylim([1e-25 1e-10]);
xlabel('$f$ $[\mathrm{Hz}]$', 'FontSize', 15, 'Interpreter', 'latex');
xlim([min(x_1) max(x_1)]);
xticks([1e-1, 1e0, 1e1, 1e2, 1e3, 1e4]);
ylabel('$PSD_1$ $[\mathrm{A^2/Hz}]$', 'FontSize', 15, 'Interpreter', 'latex');

legend({'$f_{\mathrm{s}}=83.3\,\mathrm{kHz}$', '$f_{\mathrm{s}}=50\,\mathrm{Hz}$'},...
            'FontSize', 12, 'Interpreter', 'latex', 'Orientation', 'vertical');

text(2.3, 1e-24, '$2\,\mathrm{Hz}$',  'FontSize', 14, 'Interpreter', 'latex');
text(27,  1e-24, '$25\,\mathrm{Hz}$', 'FontSize', 14, 'Interpreter', 'latex');

grid on;
grid minor
ax = gca;
ax.FontSize = 14;